#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_REMQUO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_REMQUO_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/remquo.hpp>

#endif
